@@ -60,9 +60,6 @@ main(int argc, char **argv) {
     LIBXML_TEST_VERSION
     xmlLoadExtDtdDefaultValue = XML_DETECT_IDS | XML_COMPLETE_ATTRS;
     xmlSubstituteEntitiesDefault(1);
-#ifndef XMLSEC_NO_XSLT
-    xmlIndentTreeOutput = 1;
-#endif /* XMLSEC_NO_XSLT */
 
     /* Init libxslt */
 #ifndef XMLSEC_NO_XSLT
@@ -168,7 +165,7 @@ decrypt_file(xmlSecKeysMngrPtr mngr, const char* enc_file) {
     assert(enc_file);
 
     /* load template */
-    doc = xmlParseFile(enc_file);
+    doc = xmlReadFile(enc_file, NULL, XML_PARSE_PEDANTIC | XML_PARSE_NONET);
     if ((doc == NULL) || (xmlDocGetRootElement(doc) == NULL)){
         fprintf(stderr, "Error: unable to parse file \"%s\"\n", enc_file);
         goto done;
@@ -291,10 +288,10 @@ static xmlSecKeyStoreKlass files_keys_store_klass = {
     NULL,                               /* xmlSecKeyStoreInitializeMethod initialize; */
     NULL,                               /* xmlSecKeyStoreFinalizeMethod finalize; */
     files_keys_store_find_key,          /* xmlSecKeyStoreFindKeyMethod findKey; */
+    NULL,                               /* xmlSecKeyStoreFindKeyFromX509DataMethod findKeyFromX509Data; */
 
     /* reserved for the future */
     NULL,                               /* void* reserved0; */
-    NULL,                               /* void* reserved1; */
 };
 
 /**
@@ -347,7 +344,7 @@ files_keys_store_find_key(xmlSecKeyStorePtr store, const xmlChar* name, xmlSecKe
 
     if((keyInfoCtx->keyReq.keyId == xmlSecKeyDataDsaId) || (keyInfoCtx->keyReq.keyId == xmlSecKeyDataRsaId)) {
         /* load key from a pem file, if key is not found then it's an error (is it?) */
-        key = xmlSecCryptoAppKeyLoad((const char*)name, xmlSecKeyDataFormatPem, NULL, NULL, NULL);
+        key = xmlSecCryptoAppKeyLoadEx((const char*)name, xmlSecKeyDataTypePrivate, xmlSecKeyDataFormatPem, NULL, NULL, NULL);
         if(key == NULL) {
             fprintf(stderr,"Error: failed to load public pem key from \"%s\"\n", name);
             return(NULL);
@@ -370,4 +367,3 @@ files_keys_store_find_key(xmlSecKeyStorePtr store, const xmlChar* name, xmlSecKe
 
     return(key);
 }
-
