@@ -4,7 +4,7 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_OPENSSL_CRYPTO_H__
 #define __XMLSEC_OPENSSL_CRYPTO_H__
@@ -17,7 +17,7 @@
 
 #include <openssl/err.h>
 #include <openssl/opensslv.h>
-#ifndef OPENSSL_IS_BORINGSSL
+#if !defined(OPENSSL_IS_BORINGSSL) && !defined(OPENSSL_IS_AWSLC)
 #include <openssl/opensslconf.h>
 #endif /* OPENSSL_IS_BORINGSSL */
 
@@ -45,19 +45,13 @@ extern "C" {
  * What version of the openssl API do we have? (also see configure.ac)
  *
  *******************************************************************/
-#if defined(LIBRESSL_VERSION_NUMBER) && LIBRESSL_VERSION_NUMBER >= 0x20700000L
-/* LibreSSL 2.7 implements (most of) OpenSSL 1.1 API */
-#define XMLSEC_OPENSSL_API_110      1
+#if defined(LIBRESSL_VERSION_NUMBER) && LIBRESSL_VERSION_NUMBER >= 0x30500000L
+/* LibreSSL implements (most of) OpenSSL 1.1 API */
+#define XMLSEC_OPENSSL_API_111      1
 #elif OPENSSL_VERSION_NUMBER >= 0x30000000L
 #define XMLSEC_OPENSSL_API_300      1
 #elif OPENSSL_VERSION_NUMBER >= 0x10101000L
 #define XMLSEC_OPENSSL_API_111      1
-#define XMLSEC_OPENSSL_API_110      1
-#elif OPENSSL_VERSION_NUMBER >= 0x10100000L
-#define XMLSEC_OPENSSL_API_110      1
-#if defined(_MSC_VER) || defined(__GNUC__) || defined(__clang__)
-#pragma message("Support for OpenSSL before version 1.1.1 is deprecated and will be removed in the future versions of XMLSec library")
-#endif /* defined(_MSC_VER) || defined(__GNUC__) || defined(__clang__) */
 #else  /* OPENSSL_VERSION_NUMBER */
 #error "This version of OpenSSL library is not supported"
 #endif /* OPENSSL_VERSION_NUMBER */
@@ -413,18 +407,6 @@ XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformDhEsGetKlass(void);
  *******************************************************************/
 #ifndef XMLSEC_NO_EC
 
-/**
- * xmlSecOpenSSLKeyDataEcdsaId:
- *
- * Deprecated. The EC key klass.
- */
-#define xmlSecOpenSSLKeyDataEcdsaId xmlSecOpenSSLKeyDataEcId
-XMLSEC_DEPRECATED XMLSEC_CRYPTO_EXPORT xmlSecKeyDataId    xmlSecOpenSSLKeyDataEcdsaGetKlass     (void);
-XMLSEC_DEPRECATED XMLSEC_CRYPTO_EXPORT int                xmlSecOpenSSLKeyDataEcdsaAdoptEvp     (xmlSecKeyDataPtr data,
-                                                                                                 EVP_PKEY* pKey);
-XMLSEC_DEPRECATED XMLSEC_CRYPTO_EXPORT EVP_PKEY*          xmlSecOpenSSLKeyDataEcdsaGetEvp       (xmlSecKeyDataPtr data);
-
-
 /**
  * xmlSecOpenSSLKeyDataEcId:
  *
@@ -560,7 +542,7 @@ XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformEcdhGetKlass(void);
 
 /********************************************************************
  *
- * GOST2001 transform
+ * GOST 2001 keys and ransforms
  *
  *******************************************************************/
 
@@ -573,6 +555,15 @@ XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformEcdhGetKlass(void);
         xmlSecOpenSSLKeyDataGost2001GetKlass()
 XMLSEC_CRYPTO_EXPORT xmlSecKeyDataId    xmlSecOpenSSLKeyDataGost2001GetKlass   (void);
 
+/**
+ * xmlSecOpenSSLTransformGostR3411_94Id:
+ *
+ * The GOSTR3411_94 digest transform klass.
+ */
+#define xmlSecOpenSSLTransformGostR3411_94Id \
+        xmlSecOpenSSLTransformGostR3411_94GetKlass()
+XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformGostR3411_94GetKlass(void);
+
 /**
  * xmlSecOpenSSLTransformGost2001GostR3411_94Id:
  *
@@ -582,15 +573,6 @@ XMLSEC_CRYPTO_EXPORT xmlSecKeyDataId    xmlSecOpenSSLKeyDataGost2001GetKlass   (
         xmlSecOpenSSLTransformGost2001GostR3411_94GetKlass()
 XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformGost2001GostR3411_94GetKlass(void);
 
-
-/**
- * xmlSecOpenSSLTransformGostR3411_94Id:
- *
- * The GOSTR3411_94 signature transform klass.
- */
-#define xmlSecOpenSSLTransformGostR3411_94Id \
-        xmlSecOpenSSLTransformGostR3411_94GetKlass()
-XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformGostR3411_94GetKlass(void);
 #endif /* XMLSEC_NO_GOST */
 
 
@@ -918,6 +900,7 @@ XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformRsaSha384GetKlass(v
 XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformRsaSha512GetKlass(void);
 #endif /* XMLSEC_NO_SHA512 */
 
+#ifndef XMLSEC_NO_RSA_PKCS15
 /**
  * xmlSecOpenSSLTransformRsaPkcs1Id:
  *
@@ -926,7 +909,9 @@ XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformRsaSha512GetKlass(v
 #define xmlSecOpenSSLTransformRsaPkcs1Id \
         xmlSecOpenSSLTransformRsaPkcs1GetKlass()
 XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformRsaPkcs1GetKlass(void);
+#endif /* XMLSEC_NO_RSA_PKCS15 */
 
+#ifndef XMLSEC_NO_RSA_OAEP
 /**
  * xmlSecOpenSSLTransformRsaOaepId:
  *
@@ -944,6 +929,7 @@ XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformRsaOaepGetKlass(voi
 #define xmlSecOpenSSLTransformRsaOaepEnc11Id \
         xmlSecOpenSSLTransformRsaOaepEnc11GetKlass()
 XMLSEC_CRYPTO_EXPORT xmlSecTransformId xmlSecOpenSSLTransformRsaOaepEnc11GetKlass(void);
+#endif /* XMLSEC_NO_RSA_OAEP */
 
 #ifndef XMLSEC_NO_SHA1
 /**
