@@ -1,17 +1,15 @@
 /*
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
+ * C14N transform implementation.
  *
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 /**
- * SECTION:c14n
- * @Short_description: C14N transform implementation.
- * @Stability: Private
- *
+ * SECTION:transforms
  */
 #include "globals.h"
 
@@ -314,8 +312,8 @@ xmlSecTransformC14NPopBin(xmlSecTransformPtr transform, xmlSecByte* data,
         if(outSize > maxDataSize) {
             outSize = maxDataSize;
         }
-        if(outSize > XMLSEC_TRANSFORM_BINARY_CHUNK) {
-            outSize = XMLSEC_TRANSFORM_BINARY_CHUNK;
+        if(outSize > transformCtx->binaryChunkSize) {
+            outSize = transformCtx->binaryChunkSize;
         }
         if(outSize > 0) {
             xmlSecAssert2(xmlSecBufferGetData(&(transform->outBuf)), -1);
@@ -734,4 +732,3 @@ xmlSecTransformId
 xmlSecTransformRemoveXmlTagsC14NGetKlass(void) {
     return(&xmlSecTransformRemoveXmlTagsC14NKlass);
 }
-
