@@ -5,7 +5,7 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 /**
  * SECTION:app
@@ -23,8 +23,8 @@
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/keys.h>
 #include <xmlsec/errors.h>
-#include <xmlsec/private.h>
 #include <xmlsec/transforms.h>
+#include <xmlsec/private.h>
 
 #include <xmlsec/gcrypt/app.h>
 #include <xmlsec/gcrypt/crypto.h>
@@ -43,7 +43,7 @@
  * Returns: 0 on success or a negative value otherwise.
  */
 int
-xmlSecGCryptAppInit(const char* config ATTRIBUTE_UNUSED) {
+xmlSecGCryptAppInit(const char* config XMLSEC_ATTRIBUTE_UNUSED) {
     gcry_error_t err;
     /* Secure memory initialisation based on documentation from:
          http://www.gnupg.org/documentation/manuals/gcrypt/Initializing-the-library.html
@@ -161,7 +161,7 @@ xmlSecGCryptAppShutdown(void) {
  * Returns: pointer to the key or NULL if an error occurs.
  */
 xmlSecKeyPtr
-xmlSecGCryptAppKeyLoadEx(const char *filename, xmlSecKeyDataType type ATTRIBUTE_UNUSED, xmlSecKeyDataFormat format,
+xmlSecGCryptAppKeyLoadEx(const char *filename, xmlSecKeyDataType type XMLSEC_ATTRIBUTE_UNUSED, xmlSecKeyDataFormat format,
     const char *pwd, void* pwdCallback, void* pwdCallbackCtx
 ) {
     xmlSecKeyPtr key;
@@ -217,9 +217,9 @@ xmlSecGCryptAppKeyLoadEx(const char *filename, xmlSecKeyDataType type ATTRIBUTE_
 xmlSecKeyPtr
 xmlSecGCryptAppKeyLoadMemory(const xmlSecByte* data, xmlSecSize dataSize,
                         xmlSecKeyDataFormat format,
-                        const char *pwd ATTRIBUTE_UNUSED,
-                        void* pwdCallback ATTRIBUTE_UNUSED,
-                        void* pwdCallbackCtx ATTRIBUTE_UNUSED)
+                        const char *pwd XMLSEC_ATTRIBUTE_UNUSED,
+                        void* pwdCallback XMLSEC_ATTRIBUTE_UNUSED,
+                        void* pwdCallbackCtx XMLSEC_ATTRIBUTE_UNUSED)
 {
     xmlSecKeyPtr key = NULL;
     xmlSecKeyDataPtr key_data = NULL;
@@ -238,11 +238,11 @@ xmlSecGCryptAppKeyLoadMemory(const xmlSecByte* data, xmlSecSize dataSize,
         }
         break;
     case xmlSecKeyDataFormatPem:
-        xmlSecNotImplementedError("xmlSecKeyDataFormatPem");
+        xmlSecNotImplementedError("GCrypt doesn't support PEM keys");
         return (NULL);
 #ifndef XMLSEC_NO_X509
     case xmlSecKeyDataFormatPkcs12:
-        xmlSecNotImplementedError("xmlSecKeyDataFormatPkcs12");
+        xmlSecNotImplementedError("GCrypt doesn't support PKCS12");
         return (NULL);
 #endif /* XMLSEC_NO_X509 */
     default:
@@ -293,8 +293,7 @@ xmlSecGCryptAppKeyCertLoad(xmlSecKeyPtr key, const char* filename,
     xmlSecAssert2(filename != NULL, -1);
     xmlSecAssert2(format != xmlSecKeyDataFormatUnknown, -1);
 
-    /* GCrypt  does not support X509 certificates */
-    xmlSecNotImplementedError(NULL);
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(-1);
 }
 
@@ -320,8 +319,7 @@ xmlSecGCryptAppKeyCertLoadMemory(xmlSecKeyPtr key,
     xmlSecAssert2(dataSize > 0, -1);
     xmlSecAssert2(format != xmlSecKeyDataFormatUnknown, -1);
 
-    /* GCrypt  does not support X509 certificates */
-    xmlSecNotImplementedError(NULL);
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(-1);
 }
 
@@ -342,13 +340,12 @@ xmlSecGCryptAppKeyCertLoadMemory(xmlSecKeyPtr key,
  */
 xmlSecKeyPtr
 xmlSecGCryptAppPkcs12Load(const char *filename,
-                          const char *pwd ATTRIBUTE_UNUSED,
-                          void* pwdCallback ATTRIBUTE_UNUSED,
-                          void* pwdCallbackCtx ATTRIBUTE_UNUSED) {
+                          const char *pwd XMLSEC_ATTRIBUTE_UNUSED,
+                          void* pwdCallback XMLSEC_ATTRIBUTE_UNUSED,
+                          void* pwdCallbackCtx XMLSEC_ATTRIBUTE_UNUSED) {
     xmlSecAssert2(filename != NULL, NULL);
 
-    /* GCrypt  does not support X509 certificates */
-    xmlSecNotImplementedError(NULL);
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(NULL);
 }
 
@@ -370,14 +367,13 @@ xmlSecGCryptAppPkcs12Load(const char *filename,
  */
 xmlSecKeyPtr
 xmlSecGCryptAppPkcs12LoadMemory(const xmlSecByte* data, xmlSecSize dataSize,
-                           const char *pwd ATTRIBUTE_UNUSED,
-                           void* pwdCallback ATTRIBUTE_UNUSED,
-                           void* pwdCallbackCtx ATTRIBUTE_UNUSED) {
+                           const char *pwd XMLSEC_ATTRIBUTE_UNUSED,
+                           void* pwdCallback XMLSEC_ATTRIBUTE_UNUSED,
+                           void* pwdCallbackCtx XMLSEC_ATTRIBUTE_UNUSED) {
     xmlSecAssert2(data != NULL, NULL);
     xmlSecAssert2(dataSize > 0, NULL);
 
-    /* GCrypt  does not support X509 certificates */
-    xmlSecNotImplementedError(NULL);
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(NULL);
 }
 
@@ -400,13 +396,12 @@ int
 xmlSecGCryptAppKeysMngrCertLoad(xmlSecKeysMngrPtr mngr,
                                 const char *filename,
                                 xmlSecKeyDataFormat format,
-                                xmlSecKeyDataType type ATTRIBUTE_UNUSED) {
+                                xmlSecKeyDataType type XMLSEC_ATTRIBUTE_UNUSED) {
     xmlSecAssert2(mngr != NULL, -1);
     xmlSecAssert2(filename != NULL, -1);
     xmlSecAssert2(format != xmlSecKeyDataFormatUnknown, -1);
 
-    /* GCrypt  does not support X509 certificates */
-    xmlSecNotImplementedError(NULL);
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(-1);
 }
 
@@ -428,8 +423,7 @@ xmlSecGCryptAppKeysMngrCrlLoad(xmlSecKeysMngrPtr mngr, const char *filename, xml
     xmlSecAssert2(filename != NULL, -1);
     xmlSecAssert2(format != xmlSecKeyDataFormatUnknown, -1);
 
-    /* GCrypt  does not support X509 certificates */
-    xmlSecNotImplementedError(NULL);
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(-1);
 }
 
@@ -453,14 +447,13 @@ xmlSecGCryptAppKeysMngrCertLoadMemory(xmlSecKeysMngrPtr mngr,
                                       const xmlSecByte* data,
                                       xmlSecSize dataSize,
                                       xmlSecKeyDataFormat format,
-                                      xmlSecKeyDataType type ATTRIBUTE_UNUSED) {
+                                      xmlSecKeyDataType type XMLSEC_ATTRIBUTE_UNUSED) {
     xmlSecAssert2(mngr != NULL, -1);
     xmlSecAssert2(data != NULL, -1);
     xmlSecAssert2(dataSize > 0, -1);
     xmlSecAssert2(format != xmlSecKeyDataFormatUnknown, -1);
 
-    /* GCrypt  does not support X509 certificates */
-    xmlSecNotImplementedError(NULL);
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(-1);
 }
 
@@ -505,7 +498,6 @@ xmlSecGCryptAppDefaultKeysMngrInit(xmlSecKeysMngrPtr mngr) {
         return(-1);
     }
 
-    /* TODO */
     mngr->getKey = xmlSecKeysMngrGetKey;
     return(0);
 }
@@ -566,7 +558,7 @@ xmlSecGCryptAppDefaultKeysMngrVerifyKey(xmlSecKeysMngrPtr mngr, xmlSecKeyPtr key
     xmlSecAssert2(key != NULL, -1);
     xmlSecAssert2(keyInfoCtx != NULL, -1);
 
-    xmlSecNotImplementedError("xmlSecGCryptAppDefaultKeysMngrVerifyKey");
+    xmlSecNotImplementedError("GCrypt doesn't support X509 certificates");
     return(-1);
 }
 
@@ -647,5 +639,6 @@ xmlSecGCryptAppDefaultKeysMngrSave(xmlSecKeysMngrPtr mngr, const char* filename,
  */
 void*
 xmlSecGCryptAppGetDefaultPwdCallback(void) {
+    /* TODO: GCrypt doesn't support password callback */
     return(NULL);
 }
