@@ -26,6 +26,7 @@
 #include <xmlsec/keys.h>
 #include <xmlsec/transforms.h>
 #include <xmlsec/xmltree.h>
+#include <xmlsec/private.h>
 
 #include <xmlsec/mscng/certkeys.h>
 #include <xmlsec/mscng/crypto.h>
@@ -41,6 +42,7 @@ struct _xmlSecMSCngKeyDataCtx {
     PCCERT_CONTEXT cert;
     NCRYPT_KEY_HANDLE privkey;
     BCRYPT_KEY_HANDLE pubkey;
+    BOOL privkeyNeedsFree;
 };
 
 XMLSEC_KEY_DATA_DECLARE(MSCngKeyData, xmlSecMSCngKeyDataCtx)
@@ -64,28 +66,47 @@ xmlSecMSCngKeyDataCertGetPubkey(PCCERT_CONTEXT cert, BCRYPT_KEY_HANDLE* key) {
 }
 
 static int
-xmlSecMSCngKeyDataCertGetPrivkey(PCCERT_CONTEXT cert, NCRYPT_KEY_HANDLE* key) {
+xmlSecMSCngKeyDataCertGetPrivkey(PCCERT_CONTEXT cert, NCRYPT_KEY_HANDLE* key, BOOL* needsFree) {
     int ret;
 
     xmlSecAssert2(cert != NULL, -1);
     xmlSecAssert2(key != NULL, -1);
+    xmlSecAssert2(needsFree != NULL, -1);
 
-    DWORD keySpec = 0;
-    BOOL callerFree = FALSE;
-
-    ret = CryptAcquireCertificatePrivateKey(
-        cert,
-        CRYPT_ACQUIRE_COMPARE_KEY_FLAG | CRYPT_ACQUIRE_ONLY_NCRYPT_KEY_FLAG,
-        NULL,
-        key,
-        &keySpec,
-        &callerFree);
-    if(ret == FALSE) {
-        xmlSecMSCngLastError("CryptAcquireCertificatePrivateKey", NULL);
-        return(-1);
+    /* try non persistent key */
+    CERT_KEY_CONTEXT ckc;
+    DWORD dwCkcLen = sizeof(ckc);
+    if (CertGetCertificateContextProperty(cert, CERT_KEY_CONTEXT_PROP_ID, &ckc, &dwCkcLen)) {
+        (*key) = ckc.hNCryptKey;
+        (*needsFree) = FALSE; /* this key doesnt need NCryptFreeObject */
+        return(0);
     }
 
-    return(0);
+    /* try persistent key */
+    DWORD dwData = 0;
+    DWORD dwDataLen = sizeof(dwData);
+    if (CertGetCertificateContextProperty(cert, CERT_KEY_SPEC_PROP_ID, &dwData, &dwDataLen)) {
+        DWORD keySpec = 0;
+        BOOL fCallerFreeProvOrNCryptKey = FALSE;
+        ret = CryptAcquireCertificatePrivateKey(
+            cert,
+            CRYPT_ACQUIRE_COMPARE_KEY_FLAG | CRYPT_ACQUIRE_ONLY_NCRYPT_KEY_FLAG,
+            NULL,
+            key,
+            &keySpec,
+            &fCallerFreeProvOrNCryptKey);
+        if (ret == FALSE) {
+            xmlSecMSCngLastError("CryptAcquireCertificatePrivateKey", NULL);
+            return(-1);
+        }
+        (*needsFree) = TRUE;
+        return(0);
+    }
+
+
+    /* no luck */
+    xmlSecMSCngLastError("CertGetCertificateContextProperty(): cert doesn't have private key", NULL);
+    return(-1);
 }
 
 /**
@@ -116,15 +137,17 @@ xmlSecMSCngKeyDataAdoptCert(xmlSecKeyDataPtr data, PCCERT_CONTEXT cert, xmlSecKe
 
     /* acquire the CNG key handle from the certificate */
     if((type & xmlSecKeyDataTypePrivate) != 0) {
-        NCRYPT_KEY_HANDLE hPrivKey;
+        NCRYPT_KEY_HANDLE hPrivKey = 0;
+        BOOL needsFree = TRUE;
 
-        ret = xmlSecMSCngKeyDataCertGetPrivkey(cert, &hPrivKey);
+        ret = xmlSecMSCngKeyDataCertGetPrivkey(cert, &hPrivKey, &needsFree);
         if(ret < 0) {
             xmlSecInternalError("xmlSecMSCngKeyDataCertGetPrivkey", NULL);
             return(-1);
         }
 
         ctx->privkey = hPrivKey;
+        ctx->privkeyNeedsFree = needsFree;
     }
 
     ret = xmlSecMSCngKeyDataCertGetPubkey(cert, &hPubKey);
@@ -307,7 +330,7 @@ xmlSecMSCngKeyDataFinalize(xmlSecKeyDataPtr data) {
     ctx = xmlSecMSCngKeyDataGetCtx(data);
     xmlSecAssert(ctx != NULL);
 
-    if(ctx->privkey != 0) {
+    if((ctx->privkey != 0) && (ctx->privkeyNeedsFree == TRUE)) {
         status = NCryptFreeObject(ctx->privkey);
         if(status != STATUS_SUCCESS) {
             xmlSecMSCngNtError("BCryptDestroyKey", NULL, status);
@@ -364,7 +387,7 @@ xmlSecMSCngKeyDataDuplicate(xmlSecKeyDataPtr dst, xmlSecKeyDataPtr src) {
     }
 
     if(srcCtx->privkey != 0) {
-        ret = xmlSecMSCngKeyDataCertGetPrivkey(dstCtx->cert, &dstCtx->privkey);
+        ret = xmlSecMSCngKeyDataCertGetPrivkey(dstCtx->cert, &dstCtx->privkey, &dstCtx->privkeyNeedsFree);
         if(ret < 0) {
             xmlSecInternalError("xmlSecMSCngKeyDataCertGetPrivkey", NULL);
             return(-1);
@@ -440,7 +463,7 @@ xmlSecMSCngKeyDataDuplicate(xmlSecKeyDataPtr dst, xmlSecKeyDataPtr src) {
                 break;
 #endif
             default:
-                xmlSecNotImplementedError(NULL);
+                xmlSecNotImplementedError2("Unexpected key magic value: %llu", (unsigned long long)(((BCRYPT_KEY_BLOB*)pbBlob)->Magic));
                 xmlFree(pbBlob);
                 return(-1);
         }
@@ -451,8 +474,7 @@ xmlSecMSCngKeyDataDuplicate(xmlSecKeyDataPtr dst, xmlSecKeyDataPtr src) {
             NULL,
             0);
         if(status != STATUS_SUCCESS) {
-            xmlSecMSCngNtError("BCryptOpenAlgorithmProvider",
-                NULL, status);
+            xmlSecMSCngNtError("BCryptOpenAlgorithmProvider", NULL, status);
             xmlFree(pbBlob);
             return(-1);
         }
@@ -466,8 +488,7 @@ xmlSecMSCngKeyDataDuplicate(xmlSecKeyDataPtr dst, xmlSecKeyDataPtr src) {
             cbBlob,
             0);
         if(status != STATUS_SUCCESS) {
-            xmlSecMSCngNtError("BCryptImportKeyPair",
-                NULL, status);
+            xmlSecMSCngNtError("BCryptImportKeyPair", NULL, status);
             xmlFree(pbBlob);
             BCryptCloseAlgorithmProvider(hAlg, 0);
             return(-1);
@@ -518,7 +539,7 @@ static xmlSecKeyDataKlass xmlSecMSCngKeyDataDEREncodedKeyValueKlass = {
     /* get info */
     NULL,                                       /* xmlSecKeyDataGetTypeMethod getType; */
     NULL,                                       /* xmlSecKeyDataGetSizeMethod getSize; */
-    NULL,                                       /* xmlSecKeyDataGetIdentifier getIdentifier; */
+    NULL,                                       /* DEPRECATED xmlSecKeyDataGetIdentifier getIdentifier; */
 
     /* read/write */
     xmlSecMSCngKeyDataDEREncodedKeyValueXmlRead,     /* xmlSecKeyDataXmlReadMethod xmlRead; */
@@ -851,7 +872,6 @@ xmlSecMSCngKeyDataDsaRead(xmlSecKeyDataId id, xmlSecKeyValueDsaPtr dsaValue) {
     dsakey->dwMagic = BCRYPT_DSA_PUBLIC_MAGIC;
     XMLSEC_SAFE_CAST_SIZE_TO_UINT(pSize, dsakey->cbKey, goto done, xmlSecKeyDataKlassGetName(id));
 
-    /* todo: add support for J, seed, pgencounter */
     memset(dsakey->Count, -1, sizeof(dsakey->Count));
     memset(dsakey->Seed, -1, sizeof(dsakey->Seed));
 
@@ -932,7 +952,7 @@ done:
 static int
 xmlSecMSCngKeyDataDsaWrite(xmlSecKeyDataId id, xmlSecKeyDataPtr data,
                         xmlSecKeyValueDsaPtr dsaValue,
-                        int writePrivateKey ATTRIBUTE_UNUSED) {
+                        int writePrivateKey XMLSEC_ATTRIBUTE_UNUSED) {
     xmlSecMSCngKeyDataCtxPtr ctx;
     NTSTATUS status;
     xmlSecBuffer buf;
@@ -1210,7 +1230,7 @@ static xmlSecKeyDataKlass xmlSecMSCngKeyDataDsaKlass = {
     /* get info */
     xmlSecMSCngKeyDataDsaGetType,               /* xmlSecKeyDataGetTypeMethod getType; */
     xmlSecMSCngKeyDataDsaGetSize,               /* xmlSecKeyDataGetSizeMethod getSize; */
-    NULL,                                       /* xmlSecKeyDataGetIdentifier getIdentifier; */
+    NULL,                                       /* DEPRECATED xmlSecKeyDataGetIdentifier getIdentifier; */
 
     /* read/write */
     xmlSecMSCngKeyDataDsaXmlRead,               /* xmlSecKeyDataXmlReadMethod xmlRead; */
@@ -1374,7 +1394,7 @@ done:
 static int
 xmlSecMSCngKeyDataRsaWrite(xmlSecKeyDataId id, xmlSecKeyDataPtr data,
                            xmlSecKeyValueRsaPtr rsaValue,
-                           int writePrivateKey ATTRIBUTE_UNUSED) {
+                           int writePrivateKey XMLSEC_ATTRIBUTE_UNUSED) {
     xmlSecMSCngKeyDataCtxPtr ctx;
     NTSTATUS status;
     xmlSecBuffer buf;
@@ -1543,7 +1563,7 @@ xmlSecMSCngKeyDataGetSize(xmlSecKeyDataPtr data) {
         }
         xmlSecAssert2(lenlen == sizeof(length), 0);
     } else if(ctx->privkey != 0) {
-        xmlSecNotImplementedError(NULL);
+        xmlSecNotImplementedError("MSCNG doesn't support getting key length from private key");
         return(0);
     }
 
@@ -1679,7 +1699,7 @@ static xmlSecKeyDataKlass xmlSecMSCngKeyDataRsaKlass = {
     /* get info */
     xmlSecMSCngKeyDataRsaGetType,               /* xmlSecKeyDataGetTypeMethod getType; */
     xmlSecMSCngKeyDataRsaGetSize,               /* xmlSecKeyDataGetSizeMethod getSize; */
-    NULL,                                       /* xmlSecKeyDataGetIdentifier getIdentifier; */
+    NULL,                                       /* DEPRECATED xmlSecKeyDataGetIdentifier getIdentifier; */
 
     /* read/write */
     xmlSecMSCngKeyDataRsaXmlRead,               /* xmlSecKeyDataXmlReadMethod xmlRead; */
@@ -2083,7 +2103,7 @@ static xmlSecKeyDataKlass xmlSecMSCngKeyDataEcKlass = {
     /* get info */
     xmlSecMSCngKeyDataEcGetType,                /* xmlSecKeyDataGetTypeMethod getType; */
     xmlSecMSCngKeyDataEcGetSize,                /* xmlSecKeyDataGetSizeMethod getSize; */
-    NULL,                                       /* xmlSecKeyDataGetIdentifier getIdentifier; */
+    NULL,                                       /* DEPRECATED xmlSecKeyDataGetIdentifier getIdentifier; */
 
     /* read/write */
     xmlSecMSCngKeyDataEcXmlRead,                /* xmlSecKeyDataXmlReadMethod xmlRead; */
