@@ -16,8 +16,7 @@
 #include "globals.h"
 
 #include <string.h>
-#include <windows.h>
-#include <wincrypt.h>
+
 #ifndef XMLSEC_NO_GOST
 #include "csp_calg.h"
 #endif
