@@ -221,7 +221,7 @@ xmlSecNssAppAscii2UCS2Conv(PRBool toUnicode,
                            unsigned char *outBuf,
                            unsigned int   maxOutBufLen,
                            unsigned int  *outBufLen,
-                           PRBool         swapBytes ATTRIBUTE_UNUSED)
+                           PRBool         swapBytes XMLSEC_ATTRIBUTE_UNUSED)
 {
     SECItem it = { siBuffer, NULL, 0 };
 
@@ -240,8 +240,8 @@ xmlSecNssAppAscii2UCS2Conv(PRBool toUnicode,
 #ifndef XMLSEC_NO_X509
 /* rename certificate if needed */
 static SECItem *
-xmlSecNssAppNicknameCollisionCallback(SECItem *old_nick ATTRIBUTE_UNUSED,
-    PRBool *cancel, void *wincx ATTRIBUTE_UNUSED
+xmlSecNssAppNicknameCollisionCallback(SECItem *old_nick XMLSEC_ATTRIBUTE_UNUSED,
+    PRBool *cancel, void *wincx XMLSEC_ATTRIBUTE_UNUSED
 ) {
     CERTCertificate *cert = (CERTCertificate *)wincx;
     char *nick = NULL;
@@ -286,7 +286,7 @@ xmlSecNssAppNicknameCollisionCallback(SECItem *old_nick ATTRIBUTE_UNUSED,
  * Returns: pointer to the key or NULL if an error occurs.
  */
 xmlSecKeyPtr
-xmlSecNssAppKeyLoadEx(const char *filename, xmlSecKeyDataType type ATTRIBUTE_UNUSED, xmlSecKeyDataFormat format,
+xmlSecNssAppKeyLoadEx(const char *filename, xmlSecKeyDataType type XMLSEC_ATTRIBUTE_UNUSED, xmlSecKeyDataFormat format,
     const char *pwd, void* pwdCallback, void* pwdCallbackCtx
 ) {
     SECItem secItem = { siBuffer, NULL, 0 };
@@ -764,8 +764,8 @@ done:
  */
 xmlSecKeyPtr
 xmlSecNssAppPkcs12Load(const char *filename, const char *pwd,
-                       void *pwdCallback ATTRIBUTE_UNUSED,
-                       void* pwdCallbackCtx ATTRIBUTE_UNUSED) {
+                       void *pwdCallback XMLSEC_ATTRIBUTE_UNUSED,
+                       void* pwdCallbackCtx XMLSEC_ATTRIBUTE_UNUSED) {
     SECItem secItem = { siBuffer, NULL, 0 };
     xmlSecKeyPtr res;
     int ret;
@@ -807,8 +807,8 @@ xmlSecNssAppPkcs12Load(const char *filename, const char *pwd,
  */
 xmlSecKeyPtr
 xmlSecNssAppPkcs12LoadMemory(const xmlSecByte* data, xmlSecSize dataSize, const char *pwd,
-                       void *pwdCallback ATTRIBUTE_UNUSED,
-                       void* pwdCallbackCtx ATTRIBUTE_UNUSED) {
+                       void *pwdCallback XMLSEC_ATTRIBUTE_UNUSED,
+                       void* pwdCallbackCtx XMLSEC_ATTRIBUTE_UNUSED) {
     SECItem secItem = { siBuffer, NULL, 0 };
     xmlSecKeyPtr res;
     int ret;
@@ -849,8 +849,8 @@ xmlSecNssAppPkcs12LoadMemory(const xmlSecByte* data, xmlSecSize dataSize, const
  */
 xmlSecKeyPtr
 xmlSecNssAppPkcs12LoadSECItem(SECItem* secItem, const char *pwd,
-                       void *pwdCallback ATTRIBUTE_UNUSED,
-                       void* pwdCallbackCtx ATTRIBUTE_UNUSED) {
+                       void *pwdCallback XMLSEC_ATTRIBUTE_UNUSED,
+                       void* pwdCallbackCtx XMLSEC_ATTRIBUTE_UNUSED) {
     xmlSecKeyPtr key = NULL;
     xmlSecKeyDataPtr keyValueData = NULL;
     xmlSecKeyDataPtr x509Data = NULL;
@@ -1583,7 +1583,7 @@ xmlSecNssAppDefaultKeysMngrVerifyKey(xmlSecKeysMngrPtr mngr, xmlSecKeyPtr key, x
     xmlSecAssert2(key != NULL, -1);
     xmlSecAssert2(keyInfoCtx != NULL, -1);
 
-    xmlSecNotImplementedError("X509 support is disabled");
+    xmlSecNotImplementedError("X509 support is disabled during compilation");
     return(-1);
 
 #endif /* XMLSEC_NO_X509 */
@@ -1666,5 +1666,6 @@ xmlSecNssAppDefaultKeysMngrSave(xmlSecKeysMngrPtr mngr, const char* filename, xm
  */
 void*
 xmlSecNssAppGetDefaultPwdCallback(void) {
+    /* TODO: NSS doesn't support password callback */
     return(NULL);
 }
