@@ -6,7 +6,7 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 /**
  * SECTION:x509
@@ -50,7 +50,7 @@
 #include <openssl/x509v3.h>
 #include <openssl/asn1.h>
 
-#ifdef OPENSSL_IS_BORINGSSL
+#if defined(OPENSSL_IS_BORINGSSL) || defined(OPENSSL_IS_AWSLC)
 #include <openssl/mem.h>
 #endif /* OPENSSL_IS_BORINGSSL */
 
@@ -110,8 +110,6 @@ static int              xmlSecOpenSSLKeyDataX509XmlWrite        (xmlSecKeyDataId
                                                                  xmlSecKeyPtr key,
                                                                  xmlNodePtr node,
                                                                  xmlSecKeyInfoCtxPtr keyInfoCtx);
-static xmlSecKeyDataType xmlSecOpenSSLKeyDataX509GetType        (xmlSecKeyDataPtr data);
-static const xmlChar*   xmlSecOpenSSLKeyDataX509GetIdentifier   (xmlSecKeyDataPtr data);
 
 static void             xmlSecOpenSSLKeyDataX509DebugDump       (xmlSecKeyDataPtr data,
                                                                  FILE* output);
@@ -155,9 +153,9 @@ static xmlSecKeyDataKlass xmlSecOpenSSLKeyDataX509Klass = {
     NULL,                                       /* xmlSecKeyDataGenerateMethod generate; */
 
     /* get info */
-    xmlSecOpenSSLKeyDataX509GetType,            /* xmlSecKeyDataGetTypeMethod getType; */
+    NULL,                                       /* xmlSecKeyDataGetTypeMethod getType; */
     NULL,                                       /* xmlSecKeyDataGetSizeMethod getSize; */
-    xmlSecOpenSSLKeyDataX509GetIdentifier,      /* xmlSecKeyDataGetIdentifier getIdentifier; */
+    NULL,                                       /* DEPRECATED xmlSecKeyDataGetIdentifier getIdentifier; */
 
     /* read/write */
     xmlSecOpenSSLKeyDataX509XmlRead,            /* xmlSecKeyDataXmlReadMethod xmlRead; */
@@ -211,7 +209,7 @@ xmlSecOpenSSLKeyDataX509GetKeyCert(xmlSecKeyDataPtr data) {
 static int
 xmlSecOpenSSLKeyDataX509AddCertInternal(xmlSecOpenSSLX509DataCtxPtr ctx, X509* cert, int keyCert) {
     X509* dup;
-    int ret;
+    xmlSecOpenSSLSizeT ret;
 
     xmlSecAssert2(ctx != NULL, -1);
     xmlSecAssert2(cert != NULL, -1);
@@ -332,7 +330,7 @@ xmlSecOpenSSLKeyDataX509AdoptCert(xmlSecKeyDataPtr data, X509* cert) {
 X509*
 xmlSecOpenSSLKeyDataX509GetCert(xmlSecKeyDataPtr data, xmlSecSize pos) {
     xmlSecOpenSSLX509DataCtxPtr ctx;
-    int iPos;
+    xmlSecOpenSSLSizeT iPos;
 
     xmlSecAssert2(xmlSecKeyDataCheckId(data, xmlSecOpenSSLKeyDataX509Id), NULL);
 
@@ -342,7 +340,7 @@ xmlSecOpenSSLKeyDataX509GetCert(xmlSecKeyDataPtr data, xmlSecSize pos) {
 
     /* to ensure that key cert is always first we put it at the first position
      * in xmlSecOpenSSLKeyDataX509AddCertInternal */
-    XMLSEC_SAFE_CAST_SIZE_TO_INT(pos, iPos, return(NULL), NULL);
+    XMLSEC_OPENSSL_SAFE_CAST_SIZE_TO_SIZE_T(pos, iPos, return(NULL), NULL);
     xmlSecAssert2(iPos < sk_X509_num(ctx->certsList), NULL);
     return(sk_X509_value(ctx->certsList, iPos));
 }
@@ -358,7 +356,7 @@ xmlSecOpenSSLKeyDataX509GetCert(xmlSecKeyDataPtr data, xmlSecSize pos) {
 xmlSecSize
 xmlSecOpenSSLKeyDataX509GetCertsSize(xmlSecKeyDataPtr data) {
     xmlSecOpenSSLX509DataCtxPtr ctx;
-    int ret;
+    xmlSecOpenSSLSizeT ret;
     xmlSecSize res;
 
     xmlSecAssert2(xmlSecKeyDataCheckId(data, xmlSecOpenSSLKeyDataX509Id), 0);
@@ -371,12 +369,7 @@ xmlSecOpenSSLKeyDataX509GetCertsSize(xmlSecKeyDataPtr data) {
     }
 
     ret = sk_X509_num(ctx->certsList);
-    if(ret < 0) {
-        xmlSecOpenSSLError("sk_X509_num", NULL);
-        return(0);
-    }
-    XMLSEC_SAFE_CAST_INT_TO_SIZE(ret, res, return(0), NULL);
-
+    XMLSEC_OPENSSL_SAFE_CAST_SIZE_T_TO_SIZE(ret, res, return(0), NULL);
     return(res);
 }
 
@@ -392,7 +385,7 @@ xmlSecOpenSSLKeyDataX509GetCertsSize(xmlSecKeyDataPtr data) {
 int
 xmlSecOpenSSLKeyDataX509AdoptCrl(xmlSecKeyDataPtr data, X509_CRL* crl) {
     xmlSecOpenSSLX509DataCtxPtr ctx;
-    int ret;
+    xmlSecOpenSSLSizeT ret;
 
     xmlSecAssert2(xmlSecKeyDataCheckId(data, xmlSecOpenSSLKeyDataX509Id), -1);
     xmlSecAssert2(crl != NULL, -1);
@@ -430,7 +423,7 @@ xmlSecOpenSSLKeyDataX509AdoptCrl(xmlSecKeyDataPtr data, X509_CRL* crl) {
 X509_CRL*
 xmlSecOpenSSLKeyDataX509GetCrl(xmlSecKeyDataPtr data, xmlSecSize pos) {
     xmlSecOpenSSLX509DataCtxPtr ctx;
-    int iPos;
+    xmlSecOpenSSLSizeT iPos;
 
     xmlSecAssert2(xmlSecKeyDataCheckId(data, xmlSecOpenSSLKeyDataX509Id), NULL);
 
@@ -439,7 +432,7 @@ xmlSecOpenSSLKeyDataX509GetCrl(xmlSecKeyDataPtr data, xmlSecSize pos) {
 
     xmlSecAssert2(ctx->crlsList != NULL, NULL);
 
-    XMLSEC_SAFE_CAST_SIZE_TO_INT(pos, iPos, return(NULL), NULL);
+    XMLSEC_OPENSSL_SAFE_CAST_SIZE_TO_SIZE_T(pos, iPos, return(NULL), NULL);
     xmlSecAssert2(iPos < sk_X509_CRL_num(ctx->crlsList), NULL);
     return(sk_X509_CRL_value(ctx->crlsList, iPos));
 }
@@ -455,7 +448,7 @@ xmlSecOpenSSLKeyDataX509GetCrl(xmlSecKeyDataPtr data, xmlSecSize pos) {
 xmlSecSize
 xmlSecOpenSSLKeyDataX509GetCrlsSize(xmlSecKeyDataPtr data) {
     xmlSecOpenSSLX509DataCtxPtr ctx;
-    int ret;
+    xmlSecOpenSSLSizeT ret;
     xmlSecSize res;
 
     xmlSecAssert2(xmlSecKeyDataCheckId(data, xmlSecOpenSSLKeyDataX509Id), 0);
@@ -468,12 +461,7 @@ xmlSecOpenSSLKeyDataX509GetCrlsSize(xmlSecKeyDataPtr data) {
     }
 
     ret = sk_X509_CRL_num(ctx->crlsList);
-    if(ret < 0) {
-        xmlSecOpenSSLError("sk_X509_CRL_num", NULL);
-        return(0);
-    }
-    XMLSEC_SAFE_CAST_INT_TO_SIZE(ret, res, return(0), NULL);
-
+    XMLSEC_OPENSSL_SAFE_CAST_SIZE_T_TO_SIZE(ret, res, return(0), NULL);
     return(res);
 }
 
@@ -563,10 +551,10 @@ xmlSecOpenSSLKeyDataX509Duplicate(xmlSecKeyDataPtr dst, xmlSecKeyDataPtr src) {
             return(-1);
         }
 #else /* XMLSEC_OPENSSL_NO_DEEP_COPY */
-        int size, ii;
+        xmlSecOpenSSLSizeT size, ii;
         X509* certSrc;
         X509* certDst;
-        int ret;
+        xmlSecOpenSSLSizeT ret;
 
         ctxDst->certsList = sk_X509_new_null();
         if(ctxDst->certsList == NULL) {
@@ -607,10 +595,10 @@ xmlSecOpenSSLKeyDataX509Duplicate(xmlSecKeyDataPtr dst, xmlSecKeyDataPtr src) {
             return(-1);
         }
 #else /* XMLSEC_OPENSSL_NO_DEEP_COPY */
-        int size, ii;
+        xmlSecOpenSSLSizeT size, ii;
         X509_CRL* crlSrc;
         X509_CRL* crlDst;
-        int ret;
+        xmlSecOpenSSLSizeT ret;
 
         ctxDst->crlsList = sk_X509_CRL_new_null();
         if(ctxDst->crlsList == NULL) {
@@ -640,7 +628,7 @@ xmlSecOpenSSLKeyDataX509Duplicate(xmlSecKeyDataPtr dst, xmlSecKeyDataPtr src) {
 
     /* keyCert: should be in the same position in certsList after copy */
     if(ctxSrc->keyCert != NULL) {
-        int ii, len;
+        xmlSecOpenSSLSizeT ii, len;
 
         len = sk_X509_num(ctxSrc->certsList);
         xmlSecAssert2(len == sk_X509_num(ctxDst->certsList), -1);
@@ -742,23 +730,6 @@ xmlSecOpenSSLKeyDataX509XmlWrite(xmlSecKeyDataId id, xmlSecKeyPtr key,
     return(0);
 }
 
-
-static xmlSecKeyDataType
-xmlSecOpenSSLKeyDataX509GetType(xmlSecKeyDataPtr data) {
-    xmlSecAssert2(xmlSecKeyDataCheckId(data, xmlSecOpenSSLKeyDataX509Id), xmlSecKeyDataTypeUnknown);
-
-    /* TODO: return verified/not verified status */
-    return(xmlSecKeyDataTypeUnknown);
-}
-
-static const xmlChar*
-xmlSecOpenSSLKeyDataX509GetIdentifier(xmlSecKeyDataPtr data) {
-    xmlSecAssert2(xmlSecKeyDataCheckId(data, xmlSecOpenSSLKeyDataX509Id), NULL);
-
-    /* TODO */
-    return(NULL);
-}
-
 static void
 xmlSecOpenSSLKeyDataX509DebugDump(xmlSecKeyDataPtr data, FILE* output) {
     X509* cert;
@@ -949,7 +920,7 @@ xmlSecOpenSSLX509CertDerWrite(X509* cert, xmlSecBufferPtr buf) {
         goto done;
     }
 
-    len = BIO_get_mem_data(mem, &data);
+    len = BIO_get_mem_data(mem, (char**)&data);
     if((len <= 0) || (data == NULL)){
         xmlSecOpenSSLError("BIO_get_mem_data", NULL);
         goto done;
@@ -1001,7 +972,7 @@ xmlSecOpenSSLX509CrlDerWrite(X509_CRL* crl, xmlSecBufferPtr buf) {
         goto done;
     }
 
-    len = BIO_get_mem_data(mem, &data);
+    len = BIO_get_mem_data(mem, (char**)&data);
     if((len <= 0) || (data == NULL)){
         xmlSecOpenSSLError("BIO_get_mem_data", NULL);
         goto done;
@@ -1186,6 +1157,7 @@ xmlSecOpenSSLX509NameWrite(X509_NAME* nm) {
     xmlChar* res = NULL;
     BIO *mem = NULL;
     xmlChar* buf = NULL;
+    xmlSecOpenSSLSizeT memBufSize;
     xmlSecSize sizeBuf;
     int lenBuf, lenRead;
     int ret;
@@ -1209,12 +1181,13 @@ xmlSecOpenSSLX509NameWrite(X509_NAME* nm) {
         goto done;
     }
 
-    lenBuf = BIO_pending(mem);
-    if(lenBuf <= 0) {
+    memBufSize = BIO_pending(mem);
+    if(memBufSize <= 0) {
         xmlSecOpenSSLError("BIO_pending", NULL);
         goto done;
     }
-    XMLSEC_SAFE_CAST_INT_TO_SIZE(lenBuf, sizeBuf, goto done, NULL);
+    XMLSEC_OPENSSL_SAFE_CAST_SIZE_T_TO_SIZE(memBufSize, sizeBuf, goto done, NULL);
+    XMLSEC_OPENSSL_SAFE_CAST_SIZE_T_TO_INT(memBufSize, lenBuf, goto done, NULL);
 
     buf = (xmlChar *)xmlMalloc(sizeBuf + 1);
     if(buf == NULL) {
@@ -1420,6 +1393,9 @@ my_timegm(struct tm *t) {
         tl += 3600;
     }
     tg = gmtime (&tl);
+    if(tg == NULL) {
+        return (-1);
+    }
     tg->tm_isdst = 0;
     tb = mktime (tg);
     if (tb == -1) {
@@ -1931,7 +1907,7 @@ static xmlSecKeyDataKlass xmlSecOpenSSLKeyDataRawX509CertKlass = {
     /* get info */
     NULL,                                       /* xmlSecKeyDataGetTypeMethod getType; */
     NULL,                                       /* xmlSecKeyDataGetSizeMethod getSize; */
-    NULL,                                       /* xmlSecKeyDataGetIdentifier getIdentifier; */
+    NULL,                                       /* DEPRECATED xmlSecKeyDataGetIdentifier getIdentifier; */
 
     /* read/write */
     NULL,                                       /* xmlSecKeyDataXmlReadMethod xmlRead; */
