@@ -41,31 +41,30 @@ var verMinorXmlSec;
 var verMicroXmlSec;
 
 /* Libxmlsec features. */
-var withCrypto = "openssl";
-var withDefaultCrypto = "openssl";
+var withCrypto = "mscng";
+var withDefaultCrypto = "mscng";
 var withOpenSSL = 0;
 var withOpenSSLVersion = "";
 var withNss = 0;
 var withMSCrypto = 0;
-var withMSCng = 0;
+var withMSCng = 1;
 var withLibXSLT = 1;
-var withIconv = 1;
-var withFTP = 0; /* disable ftp by default */
-var withHTTP = 0; /* disable http by default */
+var withIconv = 0;     /* disable iconv by default */
+var withFTP = 0;       /* disable ftp by default */
+var withHTTP = 0;      /* disable http by default */
 var withGost = 0;
 var withRsaPkcs15 = 1;
-var withLegacyCrypto = 0;
+var withLegacyFeatures = 0;
 
 /* Win32 build options. */
 var buildUnicode = 1;
 var buildDebug = 0;
 var buildWithMemcheck = 0;
-var buildWerror = 0;
+var buildWerror = 1;
 var buildPedantic = 1;
 var buildCc = "cl.exe";
 var buildCflags = "";
 var buildStatic = 1;
-var buildWithDLSupport = 1;
 var buildPrefix = ".";
 var buildBinPrefix = "$(PREFIX)\\bin";
 var buildIncPrefix = "$(PREFIX)\\include";
@@ -125,7 +124,7 @@ function usage()
 	txt += "  http:       Enable HTTP support (" + (withHTTP ? "yes" : "no") + ")\n";
 	txt += "  rsa-pkcs15: Enable RSA PKCS#1.5 key transport (" + (withRsaPkcs15 ? "yes" : "no") + ")\n";
 	txt += "  gost:	      Enable GOST algorithms (" + (withGost ? "yes" : "no") + ")\n";
-	txt += "  legacy-crypto: Enable legacy crypto algorithms (" + (withLegacyCrypto ? "yes" : "no") + ")\n";
+	txt += "  legacy-features: Enable legacy features and crypto algorithms (" + (withLegacyFeatures ? "yes" : "no") + ")\n";
 	txt += "\nWin32 build options, default value given in parentheses:\n\n";
 	txt += "  unicode:    Build Unicode version (" + (buildUnicode? "yes" : "no")  + ")\n";
 	txt += "  debug:      Build unoptimised debug executables (" + (buildDebug? "yes" : "no")  + ")\n";
@@ -135,7 +134,6 @@ function usage()
 	txt += "  cc:         Build with the specified compiler(" + buildCc  + ")\n";
 	txt += "  cflags:     Build with the specified compiler flags('" + buildCflags  + "')\n";
 	txt += "  static:     Build static xmlsec libraries (" + (buildStatic? "yes" : "no")  + ")\n";
-	txt += "  with-dl:    Enable dynamic loading of xmlsec-crypto libraries (" + (buildWithDLSupport ? "yes" : "no") + ")\n";
 	txt += "  prefix:     Base directory for the installation (" + buildPrefix + ")\n";
 	txt += "  bindir:     Directory where xmlsec and friends should be installed\n";
 	txt += "              (" + buildBinPrefix + ")\n";
@@ -150,7 +148,7 @@ function usage()
 	txt += "  lib:        Additional search path for the linker, particularily\n";
 	txt += "              where libxml library can be found (" + buildLib + ")\n";
 	txt += "\nCrypto options, default value given in parentheses:\n\n";
-	txt += "  with-openssl3-engines:    Enable dynamic loading of xmlsec-crypto libraries (" + (withOpenSSL3Engines ? "yes" : "no") + ")\n";
+	txt += "  with-openssl3-engines:    Enable ENGINE interface support for OpenSSL (" + (withOpenSSL3Engines ? "yes" : "no") + ")\n";
 	WScript.Echo(txt);
 }
 
@@ -201,7 +199,7 @@ function discoverVersion()
 	vf.WriteLine("WITH_HTTP=" + (withHTTP ? "1" : "0"));
 	vf.WriteLine("WITH_GOST=" + (withGost ? "1" : "0"));
 	vf.WriteLine("WITH_RSA_PKCS15=" + (withRsaPkcs15 ? "1" : "0"));
-	vf.WriteLine("WITH_LEGACY_CRYPTO=" + (withLegacyCrypto ? "1" : "0"));
+	vf.WriteLine("WITH_LEGACY_FEATURES=" + (withLegacyFeatures ? "1" : "0"));
 	vf.WriteLine("UNICODE=" + (buildUnicode? "1" : "0"));
 	vf.WriteLine("DEBUG=" + (buildDebug? "1" : "0"));
 	vf.WriteLine("MEMCHECK=" + (buildWithMemcheck ? "1" : "0"));
@@ -210,7 +208,6 @@ function discoverVersion()
 	vf.WriteLine("CC=" + buildCc);
 	vf.WriteLine("CFLAGS=" + buildCflags);
 	vf.WriteLine("STATIC=" + (buildStatic? "1" : "0"));
-	vf.WriteLine("WITH_DL=" + (buildWithDLSupport ? "1" : "0"));
 	vf.WriteLine("PREFIX=" + buildPrefix);
 	vf.WriteLine("BINPREFIX=" + buildBinPrefix);
 	vf.WriteLine("INCPREFIX=" + buildIncPrefix);
@@ -344,8 +341,10 @@ for (i = 0; (i < WScript.Arguments.length) && (error == 0); i++) {
 			withRsaPkcs15 = strToBool(arg.substring(opt.length + 1, arg.length));
 		else if (opt == "gost")
 			withGost = strToBool(arg.substring(opt.length + 1, arg.length));
+		else if (opt == "legacy-features")
+			withLegacyFeatures = strToBool(arg.substring(opt.length + 1, arg.length));
 		else if (opt == "legacy-crypto")
-			withLegacyCrypto = strToBool(arg.substring(opt.length + 1, arg.length));
+			withLegacyFeatures = strToBool(arg.substring(opt.length + 1, arg.length));
 		else if (opt == "unicode")
 			buildUnicode = strToBool(arg.substring(opt.length + 1, arg.length));
 		else if (opt == "debug")
@@ -363,8 +362,6 @@ for (i = 0; (i < WScript.Arguments.length) && (error == 0); i++) {
 			buildCflags = arg.substring(opt.length + 1, arg.length);
 		else if (opt == "static")
 			buildStatic = strToBool(arg.substring(opt.length + 1, arg.length));
-		else if (opt == "with-dl")
-			buildWithDLSupport = strToBool(arg.substring(opt.length + 1, arg.length));
 		else if (opt == "prefix")
 			buildPrefix = arg.substring(opt.length + 1, arg.length);
 		else if (opt == "incdir")
@@ -384,10 +381,12 @@ for (i = 0; (i < WScript.Arguments.length) && (error == 0); i++) {
 		else if (opt == "cruntime") {
 			cruntime = arg.substring(opt.length + 1, arg.length);
 			cruntimeSet = 1;
-		} else if (opt == "with-openssl3-engines")
+		} else if (opt == "with-openssl3-engines") {
 			withOpenSSL3Engines = strToBool(arg.substring(opt.length + 1, arg.length));
-		else
+		} else {
 			error = 1;
+            WScript.Echo("ERROR: Unknown option'" + opt + "'\n");
+		}
 	} else if (i == 0) {
 		if (arg == "genreadme") {
 			// This command comes from the Makefile and will not be checked
@@ -481,31 +480,30 @@ var txtOut = "\nXMLSEC configuration\n";
 txtOut += "----------------------------\n";
 txtOut += "          Use Crypto: " + withCrypto + "\n";
 txtOut += "  Use Default Crypto: " + withDefaultCrypto + "\n";
+txtOut += "           Use MSCng: " + boolToStr(withMSCng) + "\n";
 txtOut += "         Use OpenSSL: " + boolToStr(withOpenSSL) + "\n";
 txtOut += " Use OpenSSL Version: " + withOpenSSLVersion + "\n";
 txtOut += "             Use NSS: " + boolToStr(withNss) + "\n";
 txtOut += "        Use MSCrypto: " + boolToStr(withMSCrypto) + "\n";
-txtOut += "           Use MSCng: " + boolToStr(withMSCng) + "\n";
 txtOut += "         Use LibXSLT: " + boolToStr(withLibXSLT) + "\n";
 txtOut += "           Use iconv: " + boolToStr(withIconv) + "\n";
 txtOut += " Enable RSA PKCS#1.5: " + boolToStr(withRsaPkcs15) + "\n";
 txtOut += "         Enable GOST: " + boolToStr(withGost) + "\n";
-txtOut += "Enable legacy crypto: " + boolToStr(withLegacyCrypto) + "\n";
+txtOut += "Enable legacy crypto: " + boolToStr(withLegacyFeatures) + "\n";
 txtOut += "         Support FTP: " + boolToStr(withFTP) + "\n";
 txtOut += "        Support HTTP: " + boolToStr(withHTTP) + "\n";
 txtOut += "\n";
 txtOut += "Win32 build configuration\n";
 txtOut += "-------------------------\n";
+txtOut += "           Pedantic: " + boolToStr(buildPedantic) + "\n";
+txtOut += "         C compiler: " + buildCc + "\n";
+txtOut += "   C compiler flags: " + buildCflags + "\n";
 txtOut += "   C-Runtime option: " + cruntime + "\n";
 txtOut += "            Unicode: " + boolToStr(buildUnicode) + "\n";
 txtOut += "      Debug symbols: " + boolToStr(buildDebug) + "\n";
 txtOut += "           Memcheck: " + boolToStr(buildWithMemcheck) + "\n";
 txtOut += " Warnings as errors: " + boolToStr(buildWerror) + "\n";
-txtOut += "           Pedantic: " + boolToStr(buildPedantic) + "\n";
-txtOut += "         C compiler: " + buildCc + "\n";
-txtOut += "   C compiler flags: " + buildCflags + "\n";
 txtOut += " Static xmlsec libs: " + boolToStr(buildStatic) + "\n";
-txtOut += "  Enable DL support: " + boolToStr(buildWithDLSupport) + "\n";
 txtOut += "     Install prefix: " + buildPrefix + "\n";
 txtOut += "       Put tools in: " + buildBinPrefix + "\n";
 txtOut += "     Put headers in: " + buildIncPrefix + "\n";
